@@ -21,7 +21,7 @@ use Date::Tolkien::Shire::Data qw{
 use Time::Local;
 
 our $ERROR;
-our $VERSION = '1.905_01';
+our $VERSION = '1.900';
 
 sub new {
     my ( $class, $date, %arg ) = @_;
@@ -725,7 +725,7 @@ rather than common weekday names.
 
 =head1 NOTE: YEAR CALCULATION
 
-L<https://www.glyphweb.com/arda/f/fourthage.html> references a letter sent by
+L<http://www.glyphweb.com/arda/f/fourthage.html> references a letter sent by
 Tolkien in 1958 in which he estimates approximately 6000 years have passed
 since the War of the Ring and the end of the Third Age.  (Thanks to Danny
 O'Brien from sending me this link).  I took this approximate as an exact
@@ -756,7 +756,7 @@ the two calendars, however.  Thus the last day of our year is sometimes
 Tolkien, J. R. R. I<Return of the King>.  New York: Houghton Mifflin Press,
 1955.
 
-L<https://www.glyphweb.com/arda/f/fourthage.html>
+L<http://www.glyphweb.com/arda/f/fourthage.html>
 
 =head1 BUGS
 
@@ -766,11 +766,6 @@ epoch time doesn't support (currently values before 1902 or after 2037).  The
 module should automatically expand in available dates directly with epoch time
 support on your system.
 
-Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Date-Tolkien-Shire>,
-L<https://github.com/trwyant/perl-Date-Tolkien-Shire/issues>, or in
-electronic mail to the author.
-
 =head1 AUTHOR
 
 Tom Braun <tbraun@pobox.com>
@@ -781,7 +776,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 Copyright (c) 2001-2003, 2006 Tom Braun. All rights reserved.
 
-Copyright (C) 2017-2022, 2025 Thomas R. Wyant, III
+Copyright (C) 2017 Thomas R. Wyant, III
 
 The calendar implemented on this module was created by J.R.R. Tolkien,
 and the copyright is still held by his estate.  The license and
